@@ -1,4 +1,5 @@
 #include <gtk/gtk.h>
+#include <glib.h>
 #include <hildon/hildon.h>
  
 #include <libhildondesktop/libhildondesktop.h>
@@ -9,7 +10,7 @@
 
 HD_DEFINE_PLUGIN_MODULE (CountdownPlugin, countdown_plugin,      HD_TYPE_HOME_PLUGIN_ITEM)
 
-void update_content (CountdownPlugin *desktop_plugin);
+gboolean update_content (CountdownPlugin *desktop_plugin);
 
 void writeCountdownSettings (CountdownPlugin *desktop_plugin)
 {
@@ -29,7 +30,6 @@ void writeCountdownSettings (CountdownPlugin *desktop_plugin)
 	{
 		gchar *title, *date, *time;
 		gboolean showWhich[5];
-		gint displayNum;
 		gchar entry[5];
 		snprintf(entry, 5, "%d", i++);
 		gtk_tree_model_get(GTK_TREE_MODEL (desktop_plugin->entries),&iter,0,&title,1,&date,2,&time,4,&showWhich[0],5,&showWhich[1],6,&showWhich[2],7,&showWhich[3],8,&showWhich[4],-1);
@@ -67,24 +67,27 @@ void addNewCountdown_clicked(GtkButton *button, CountdownPlugin *desktop_plugin)
 
     dialog = gtk_dialog_new_with_buttons ("Add Countdown",
         NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-        GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
+        "Save", GTK_RESPONSE_ACCEPT, NULL);
     content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
     
     titleEntry = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
     hildon_entry_set_placeholder (HILDON_ENTRY (titleEntry), "What do you want to call this?");
     titleCaption = hildon_caption_new (group, "Title", titleEntry, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (titleCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), titleCaption);
 
     dateButton = hildon_date_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
     hildon_button_set_title_alignment (HILDON_BUTTON (dateButton), 0.5, 0.5);
     hildon_button_set_value_alignment (HILDON_BUTTON (dateButton), 0.5, 0.5);
     dateCaption = hildon_caption_new (group, "Date", dateButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (dateCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), dateCaption);
 
     timeButton = hildon_time_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
     hildon_button_set_title_alignment (HILDON_BUTTON (timeButton), 0.5, 0.5);
     hildon_button_set_value_alignment (HILDON_BUTTON (timeButton), 0.5, 0.5);
     timeCaption = hildon_caption_new (group, "Time", timeButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (timeCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), timeCaption);
 
     GtkHBox *hbox = GTK_HBOX (gtk_hbox_new (0, FALSE));
@@ -104,6 +107,7 @@ void addNewCountdown_clicked(GtkButton *button, CountdownPlugin *desktop_plugin)
     gtk_container_add (GTK_CONTAINER (hbox), toggleHours);
     gtk_container_add (GTK_CONTAINER (hbox), toggleMinutes);
     displayCaption = hildon_caption_new (group, "Display", GTK_WIDGET (hbox), NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (displayCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), displayCaption);
     
     gtk_widget_show_all (dialog);
@@ -154,29 +158,31 @@ void modifyCountdown_clicked (GtkButton *button, CountdownPlugin *desktop_plugin
     GtkWidget *titleCaption, *dateCaption, *timeCaption;
     GtkWidget *toggleYears, *toggleWeeks, *toggleDays, *toggleHours, *toggleMinutes;
     GtkWidget *displayCaption;
-	GtkWidget *removeCheck;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-    dialog = gtk_dialog_new_with_buttons ("Modify Countdown",
+    dialog = gtk_dialog_new_with_buttons ("Edit Countdown",
         NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-        GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
+        "Save", GTK_RESPONSE_ACCEPT, "Delete", GTK_RESPONSE_NO, NULL);
     content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
     
     titleEntry = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
     hildon_entry_set_placeholder (HILDON_ENTRY (titleEntry), "What do you want to call this?");
     titleCaption = hildon_caption_new (group, "Title", titleEntry, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (titleCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), titleCaption);
 
     dateButton = hildon_date_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
     hildon_button_set_title_alignment (HILDON_BUTTON (dateButton), 0.5, 0.5);
     hildon_button_set_value_alignment (HILDON_BUTTON (dateButton), 0.5, 0.5);
     dateCaption = hildon_caption_new (group, "Date", dateButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (dateCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), dateCaption);
 
     timeButton = hildon_time_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
     hildon_button_set_title_alignment (HILDON_BUTTON (timeButton), 0.5, 0.5);
     hildon_button_set_value_alignment (HILDON_BUTTON (timeButton), 0.5, 0.5);
     timeCaption = hildon_caption_new (group, "Time", timeButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (timeCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), timeCaption);
 
     GtkHBox *hbox = GTK_HBOX (gtk_hbox_new (0, FALSE));
@@ -191,12 +197,9 @@ void modifyCountdown_clicked (GtkButton *button, CountdownPlugin *desktop_plugin
     gtk_container_add (GTK_CONTAINER (hbox), toggleHours);
     gtk_container_add (GTK_CONTAINER (hbox), toggleMinutes);
     displayCaption = hildon_caption_new (group, "Display", GTK_WIDGET (hbox), NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (displayCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), displayCaption);
     
-	removeCheck = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	gtk_button_set_label (GTK_BUTTON (removeCheck), "Remove this entry");
-	gtk_container_add (GTK_CONTAINER (content_area), removeCheck);
-	
 	GtkTreeIter iter;
 	if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (desktop_plugin->entries), &iter, NULL, index))
 	{
@@ -255,15 +258,8 @@ void modifyCountdown_clicked (GtkButton *button, CountdownPlugin *desktop_plugin
 
 		if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (desktop_plugin->entries), &iter, NULL, index))
 		{
-			if (hildon_check_button_get_active (HILDON_CHECK_BUTTON (removeCheck)))
-			{
-				gtk_list_store_remove (desktop_plugin->entries, &iter);
-			}
-			else
-			{
-				gtk_list_store_set (GTK_LIST_STORE (desktop_plugin->entries), &iter, 0, title, 1, printDate, 2, compTime, 3, printTime, -1);
-				gtk_list_store_set (GTK_LIST_STORE (desktop_plugin->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, -1);
-			}
+			gtk_list_store_set (GTK_LIST_STORE (desktop_plugin->entries), &iter, 0, title, 1, printDate, 2, compTime, 3, printTime, -1);
+			gtk_list_store_set (GTK_LIST_STORE (desktop_plugin->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, -1);
 		}
 
         g_free (printDate);
@@ -273,21 +269,37 @@ void modifyCountdown_clicked (GtkButton *button, CountdownPlugin *desktop_plugin
 		writeCountdownSettings (desktop_plugin);
 		update_content (desktop_plugin);
     }
+	else if (response == GTK_RESPONSE_NO)
+	{
+		if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (desktop_plugin->entries), &iter, NULL, index))
+		{
+			gtk_list_store_remove (desktop_plugin->entries, &iter);
+		}
+		writeCountdownSettings (desktop_plugin);
+		update_content (desktop_plugin);
+	}
     gtk_widget_destroy (dialog);
 }
 
+void selection_changed (HildonTouchSelector *selector, GtkWidget *button)
+{
+	gchar *current_selection = NULL;
+	current_selection = hildon_touch_selector_get_current_text (selector);
+	hildon_button_set_title (HILDON_BUTTON (button), g_strconcat (current_selection, " minute(s)", NULL));
+	g_free (current_selection);
+}
+
 void globalOptions (HDHomePluginItem *hitem, CountdownPlugin *desktop_plugin)
 {
 	//g_warning ("globalOptions");
     GtkWidget *dialog, *content_area;
     GtkWidget *refreshButton;
     GtkWidget *refreshCaption;
-	GtkWidget *refreshLabel;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-    dialog = gtk_dialog_new_with_buttons ("Countdown Global Settings",
+    dialog = gtk_dialog_new_with_buttons ("Global Countdown Settings",
         NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-        GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
+        "Save", GTK_RESPONSE_ACCEPT, NULL);
     content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
     
 	GtkWidget *selector = hildon_touch_selector_new_text ();
@@ -302,18 +314,17 @@ void globalOptions (HDHomePluginItem *hitem, CountdownPlugin *desktop_plugin)
 	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, desktop_plugin->refresh);
 	
 	refreshButton = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-	hildon_button_set_title (HILDON_BUTTON (refreshButton), "Minutes between updates");
+	gchar *current_selection = hildon_touch_selector_get_current_text (HILDON_TOUCH_SELECTOR (selector));
+	hildon_button_set_title (HILDON_BUTTON (refreshButton), g_strconcat (current_selection, " minute(s)", NULL));
+	g_signal_connect (G_OBJECT (selector), "changed", G_CALLBACK (selection_changed), refreshButton);
 	
 	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (refreshButton), HILDON_TOUCH_SELECTOR (selector));
 	
-	refreshCaption = hildon_caption_new (group, "Refresh*", refreshButton, NULL, HILDON_CAPTION_MANDATORY);
+	refreshCaption = hildon_caption_new (group, "Update every", refreshButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (refreshCaption), "");
 	
     gtk_container_add (GTK_CONTAINER (content_area), refreshCaption);
-    
-	refreshLabel = gtk_label_new ("*requires restart to take effect");
-	gtk_label_set_markup (GTK_LABEL (refreshLabel), "<small>*requires restart to take effect</small>");
-	gtk_container_add (GTK_CONTAINER (content_area), refreshLabel);
-	
+
     gtk_widget_show_all (dialog);
 
     int response=gtk_dialog_run (GTK_DIALOG (dialog));
@@ -321,6 +332,13 @@ void globalOptions (HDHomePluginItem *hitem, CountdownPlugin *desktop_plugin)
     {
         desktop_plugin->refresh = hildon_picker_button_get_active (HILDON_PICKER_BUTTON (refreshButton));
 		
+		if (desktop_plugin->eventID != 0)
+		{
+			g_source_remove (desktop_plugin->eventID);
+			if (desktop_plugin->refresh > 0)
+				desktop_plugin->eventID = g_timeout_add (desktop_plugin->refresh*1000*60, (GSourceFunc)update_content, desktop_plugin);
+		}
+		
 		writeCountdownSettings (desktop_plugin);
 		update_content (desktop_plugin);
     }
@@ -398,7 +416,7 @@ void setup_make_view ( CountdownPlugin *desktop_plugin )
 			gtk_list_store_set(desktop_plugin->entries, &iter,0,title,1,date,2,time,3,readableTime,4,showWhich[0],5,showWhich[1],6,showWhich[2],7,showWhich[3],8,showWhich[4],-1);
 			snprintf(entry,5,"%d",++i);
 			found=g_key_file_has_group(keyFile,entry);
-			free(readableTime);
+			g_free(readableTime);
 			g_free(title);
 			g_free(date);
 			g_free(time);
@@ -440,7 +458,7 @@ void countdown_content_create (CountdownPlugin *desktop_plugin)
 	//g_warning ("countdown_content_create");
     desktop_plugin->contents = gtk_vbox_new (0, FALSE);
 	GtkVBox *scrollArea = GTK_VBOX (gtk_vbox_new (0, TRUE));
-    GtkLabel *label = GTK_LABEL (gtk_label_new ("Countdown widget"));
+    //GtkLabel *label = GTK_LABEL (gtk_label_new ("Countdown widget"));
 
     GtkWidget *addNewCountdown;
     addNewCountdown = hildon_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_AUTO_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
@@ -465,7 +483,7 @@ void countdown_content_create (CountdownPlugin *desktop_plugin)
     
     g_signal_connect (addNewCountdown, "clicked", G_CALLBACK (addNewCountdown_clicked), desktop_plugin);
     
-    gtk_box_pack_start (GTK_BOX (desktop_plugin->homeWidget), GTK_WIDGET (label), FALSE, FALSE, 0);
+    //gtk_box_pack_start (GTK_BOX (desktop_plugin->homeWidget), GTK_WIDGET (label), FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (desktop_plugin->homeWidget), GTK_WIDGET (hbox), FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (desktop_plugin->homeWidget), GTK_WIDGET (buttons), FALSE, FALSE, 0);
     gtk_widget_show_all (desktop_plugin->homeWidget);
@@ -473,9 +491,9 @@ void countdown_content_create (CountdownPlugin *desktop_plugin)
 	gtk_widget_hide (desktop_plugin->downButton);
 }
 
-void update_content (CountdownPlugin *desktop_plugin)
+gboolean update_content (CountdownPlugin *desktop_plugin)
 {
-	g_warning ("update_content");
+	//g_warning ("update_content");
 	GtkWidget *vbox;
 	GDate *startDate=NULL, *endDate=NULL;
 	gint startSec=0, endSec=0;
@@ -523,8 +541,6 @@ void update_content (CountdownPlugin *desktop_plugin)
 		
 		gtk_tree_model_get (GTK_TREE_MODEL (desktop_plugin->entries), &iter, 0, &title, 1, &date, 2, &time, 4, &showYears, 5, &showWeeks, 6, &showDays, 7, &showHours, 8, &showMinutes, -1);
 
-		//g_warning ("calculating time remaining... title: %s", title);
-		
 		seconds = g_ascii_strtoll (time, NULL,  10);
 		
 		g_date_set_parse (endDate, date);
@@ -543,7 +559,7 @@ void update_content (CountdownPlugin *desktop_plugin)
 		
 		if (totDays > 0)
 		{
-			tail = "left";
+			tail = g_strdup_printf ("left");
 			if (seconds < 0)
 			{
 				totDays--;
@@ -552,7 +568,7 @@ void update_content (CountdownPlugin *desktop_plugin)
 		}
 		else if (totDays < 0)
 		{
-			tail = "passed";
+			tail = g_strdup_printf ("ago");
 			if (seconds > 0)
 			{
 				totDays++;
@@ -563,18 +579,18 @@ void update_content (CountdownPlugin *desktop_plugin)
 		{
 			if (seconds < 0)
 			{
-				tail = "passed";
+				tail = g_strdup_printf ("ago");
 			}
 			else
 			{
-				tail = "left";
+				tail = g_strdup_printf ("left");
 			}
 		}
 		
 		firstShown = FALSE;
 
-		totDays=abs(totDays);
-		seconds=abs(seconds);
+		totDays=ABS(totDays);
+		seconds=ABS(seconds);
 		
 		if (showYears)
 		{
@@ -582,7 +598,7 @@ void update_content (CountdownPlugin *desktop_plugin)
 			if ((firstShown)||(years!=0)||((!showWeeks)&&(!showDays)&&(!showHours)&&(!showMinutes)))
 			{
 				firstShown = TRUE;
-				tempContent = g_strdup_printf ("%d", abs (years));
+				tempContent = g_strdup_printf ("%d", ABS (years));
 				content[index++] = g_strconcat (tempContent, " years ", NULL);
 				g_free (tempContent);
 			}
@@ -593,7 +609,7 @@ void update_content (CountdownPlugin *desktop_plugin)
 			if ((firstShown)||(weeks!=0)||((!showDays)&&(!showHours)&&(!showMinutes)))
 			{
 				firstShown = TRUE;
-				tempContent = g_strdup_printf ("%d", abs (weeks));
+				tempContent = g_strdup_printf ("%d", ABS (weeks));
 				content[index++] = g_strconcat (tempContent, " weeks ", NULL);
 				g_free (tempContent);
 			}
@@ -604,7 +620,7 @@ void update_content (CountdownPlugin *desktop_plugin)
 			if ((firstShown)||(days!=0)||((!showHours)&&(!showMinutes)))
 			{
 				firstShown = TRUE;
-				tempContent = g_strdup_printf ("%d", abs (days));
+				tempContent = g_strdup_printf ("%d", ABS (days));
 				content[index++] = g_strconcat (tempContent, " days ", NULL);
 				g_free (tempContent);
 			}
@@ -615,7 +631,7 @@ void update_content (CountdownPlugin *desktop_plugin)
 			if ((firstShown)||(hours!=0)||(!showMinutes))
 			{
 				firstShown = TRUE;
-				tempContent = g_strdup_printf ("%d", abs (hours));
+				tempContent = g_strdup_printf ("%d", ABS (hours));
 				content[index++] = g_strconcat (tempContent, " hours ", NULL);
 				g_free (tempContent);
 			}
@@ -624,7 +640,7 @@ void update_content (CountdownPlugin *desktop_plugin)
 		{
 			minutes=((totDays-(days+(weeks*7)+(years*365)))*(24*60))+((seconds/60)-(hours*60));
 			firstShown = TRUE;
-			tempContent = g_strdup_printf ("%d", abs (minutes));
+			tempContent = g_strdup_printf ("%d", ABS (minutes));
 			content[index++] = g_strconcat (tempContent, " mins ", NULL);
 			g_free (tempContent);
 		}
@@ -636,6 +652,7 @@ void update_content (CountdownPlugin *desktop_plugin)
 		hildon_button_set_title_alignment (HILDON_BUTTON (countdownButton), 0.0, 0.5);
 		hildon_button_set_value_alignment (HILDON_BUTTON (countdownButton), 0.0, 0.5);
 		hildon_button_add_size_groups (HILDON_BUTTON (countdownButton), titleGroup, valueGroup, NULL);
+		gtk_window_set_opacity (gtk_widget_get_ancestor (countdownButton, GTK_TYPE_WINDOW), 0.5);
 		
 		g_signal_connect (countdownButton, "clicked", G_CALLBACK (modifyCountdown_clicked), desktop_plugin);
 		
@@ -650,7 +667,7 @@ void update_content (CountdownPlugin *desktop_plugin)
 		g_free (date);
 		g_free (time);
 		g_free (name);
-		//g_free (tail);
+		g_free (tail);
 		g_strfreev (content);
 		
 		exists = gtk_tree_model_iter_next (GTK_TREE_MODEL (desktop_plugin->entries), &iter);
@@ -699,47 +716,96 @@ void update_content (CountdownPlugin *desktop_plugin)
 	g_date_free (startDate);
 	g_date_free (endDate);
 
+	return TRUE;
 }
 
 static void
-countdown_plugin_expose (GObject *gobject, GParamSpec *pspec, CountdownPlugin *desktop_plugin)
+countdown_plugin_check_desktop (GObject *gobject, GParamSpec *pspec, CountdownPlugin *desktop_plugin)
 {
-	g_warning ("countdown_plugin_expose");
+	//g_warning ("countdown_plugin_expose");
 	gchar *name = pspec->name;
 	gboolean status;
 	g_object_get (gobject, name, &status, NULL);
 	if (status)
 	{
-		g_warning ("true");
 		update_content (desktop_plugin);
-		if (desktop_plugin->eventID == 0 && desktop_plugin->refresh >= 0)
+		if (desktop_plugin->eventID == 0)
 		{
-			desktop_plugin->eventID = g_timeout_add (desktop_plugin->refresh*1000*60, (GSourceFunc)update_content, desktop_plugin);
+			if (desktop_plugin->refresh > 0)
+				desktop_plugin->eventID = g_timeout_add (desktop_plugin->refresh*1000*60, (GSourceFunc)update_content, desktop_plugin);
 		}
 	}
 	else if (desktop_plugin->eventID != 0)
 	{
-		g_warning ("false");
 		g_source_remove (desktop_plugin->eventID);
 		desktop_plugin->eventID = 0;
 	}
 }
 
 static void
-countdown_plugin_finalize (GObject *gobject, GParamSpec *pspec, CountdownPlugin *desktop_plugin)
+countdown_plugin_realize (GtkWidget *widget)
 {
-	g_warning ("countdown_plugin_finalize");
-	if (desktop_plugin->eventID != 0)
+	GdkScreen *screen;
+
+	screen = gtk_widget_get_screen (widget);
+	gtk_widget_set_colormap (widget,
+				   gdk_screen_get_rgba_colormap (screen));
+
+	gtk_widget_set_app_paintable (widget,
+						TRUE);
+
+	GTK_WIDGET_CLASS(g_type_class_peek_parent
+				 (GTK_FRAME_GET_CLASS(widget)))->realize(widget);
+}
+
+static gboolean
+countdown_plugin_expose_event (GtkWidget *widget, GdkEventExpose *event)
+{
+	//g_warning ("countdown_plugin_expose_event");
+	cairo_t *cr;
+	
+	if (GTK_WIDGET_DRAWABLE(widget) == FALSE){
+		return FALSE;
+	}
+
+	//g_warning ("continuing...");
+    /* Create cairo context */
+    cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
+    gdk_cairo_region (cr, event->region);
+    cairo_clip (cr);
+
+    /* Draw alpha background */
+    cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+    cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.0);
+    cairo_paint (cr);
+
+    /* Free context */
+    cairo_destroy (cr);
+	
+	return GTK_WIDGET_CLASS(g_type_class_peek_parent
+                         (GTK_FRAME_GET_CLASS(widget)))->expose_event(widget, event);
+	//return TRUE;
+}
+
+static void
+countdown_plugin_finalize (GObject *object)
+{
+	//g_warning ("countdown_plugin_finalize");
+	CountdownPlugin *desktop_plugin = COUNTDOWN_PLUGIN (object);
+	if (desktop_plugin->eventID)
+	{
 		g_source_remove (desktop_plugin->eventID);
-	//g_free (desktop_plugin->eventID);
-	g_object_unref (desktop_plugin->entries);
-	gtk_widget_destroy (desktop_plugin->homeWidget);
+	}
+	G_OBJECT_CLASS (countdown_plugin_parent_class)->finalize (object);
 }
 
 static void
 countdown_plugin_init (CountdownPlugin *desktop_plugin)
 {
 	//g_warning ("countdown_plugin_init");
+	//GdkScreen *screen = gtk_widget_get_screen (GTK_WIDGET (desktop_plugin));
+	//gtk_widget_set_colormap (GTK_WIDGET (desktop_plugin), gdk_screen_get_rgba_colormap (screen));
+	//gtk_widget_set_app_paintable (GTK_WIDGET (desktop_plugin), TRUE);
 	desktop_plugin->offset = 0;
 	desktop_plugin->eventID = 0;
 	hd_home_plugin_item_set_settings (&desktop_plugin->hitem, TRUE);
@@ -757,15 +823,22 @@ countdown_plugin_init (CountdownPlugin *desktop_plugin)
 	//update_content(desktop_plugin);
 	//if (desktop_plugin->refresh > 0)
 	//	desktop_plugin->eventID = g_timeout_add (desktop_plugin->refresh*1000*60, (GSourceFunc)update_content, desktop_plugin);
-		
-	g_signal_connect (&desktop_plugin->hitem, "notify::is-on-current-desktop", G_CALLBACK (countdown_plugin_expose), desktop_plugin);
-	g_signal_connect (&desktop_plugin->hitem, "destroy", G_CALLBACK (countdown_plugin_finalize), desktop_plugin);
+
+	g_signal_connect (&desktop_plugin->hitem, "notify::is-on-current-desktop", G_CALLBACK (countdown_plugin_check_desktop), desktop_plugin);
+	//g_signal_connect (&desktop_plugin->hitem, "destroy", G_CALLBACK (countdown_plugin_finalize), desktop_plugin);
 }
 
 static void
-countdown_plugin_class_init (CountdownPluginClass *class) {
-	//g_warning ("countdown_plugin_class_init");	
-} 
+countdown_plugin_class_init (CountdownPluginClass *klass)
+{
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+
+  object_class->finalize = countdown_plugin_finalize;
+ 
+  //widget_class->realize = countdown_plugin_realize;
+  //widget_class->expose_event = countdown_plugin_expose_event;
+}
 
 static void
 countdown_plugin_class_finalize (CountdownPluginClass *class) {
